@@ -28,6 +28,7 @@ from .cache import CacheConfig
 from .compression import CompressionConfig
 from .cors import CORSConfig
 from .csrf import CSRFConfig
+from .logging import BaseLoggingConfig
 from .openapi import OpenAPIConfig
 from .static_files import StaticFilesConfig
 from .template import TemplateConfig
@@ -129,6 +130,10 @@ class AppConfig(BaseModel):
     """
     A list of [Guard][starlite.types.Guard] callables.
     """
+    logging_config: Optional[BaseLoggingConfig]
+    """
+    An instance of [BaseLoggingConfig][starlite.config.logging.BaseLoggingConfig] subclass.
+    """
     middleware: List[Middleware]
     """
     A list of [Middleware][starlite.types.Middleware].
