@@ -15,7 +15,7 @@ from starlette.status import (
 
 
 class StarLiteException(Exception):
-    def __init__(self, *args: Any, detail: str = ""):
+    def __init__(self, *args: Any, detail: str = "") -> None:
         """Base `starlite` exception.
 
         Args:
@@ -38,6 +38,14 @@ class MissingDependencyException(StarLiteException, ImportError):
     """Missing optional dependency."""
 
 
+class WebSocketException(StarLiteException):
+    """Exception class for websocket related events."""
+
+    def __init__(self, *args: Any, detail: str, code: int = 4500) -> None:
+        super().__init__(*args, detail=detail)
+        self.code = code
+
+
 class HTTPException(StarletteHTTPException, StarLiteException):
     status_code = HTTP_500_INTERNAL_SERVER_ERROR
     """Default status code for the exception type"""
@@ -49,7 +57,7 @@ class HTTPException(StarletteHTTPException, StarLiteException):
         status_code: Optional[int] = None,
         headers: Optional[Dict[str, str]] = None,
         extra: Optional[Union[Dict[str, Any], List[Any]]] = None,
-    ):
+    ) -> None:
         """Base exception for HTTP error responses.
 
         These exceptions carry information to construct an HTTP response.
@@ -131,7 +139,7 @@ class ServiceUnavailableException(HTTPException):
 
 
 class TemplateNotFoundException(InternalServerException):
-    def __init__(self, *args: Any, template_name: str):
+    def __init__(self, *args: Any, template_name: str) -> None:
         """Referenced template could not be found.
 
         Args:
