@@ -6,6 +6,7 @@ from starlite.middleware.base import DefineMiddleware, MiddlewareProtocol
 from starlite.middleware.compression import CompressionMiddleware
 from starlite.middleware.csrf import CSRFMiddleware
 from starlite.middleware.exceptions import ExceptionHandlerMiddleware
+from starlite.middleware.logging import LoggingMiddleware, LoggingMiddlewareConfig
 from starlite.middleware.rate_limit import RateLimitConfig, RateLimitMiddleware
 
 __all__ = [
@@ -15,6 +16,8 @@ __all__ = [
     "CompressionMiddleware",
     "DefineMiddleware",
     "ExceptionHandlerMiddleware",
+    "LoggingMiddleware",
+    "LoggingMiddlewareConfig",
     "MiddlewareProtocol",
     "RateLimitConfig",
     "RateLimitMiddleware",
