@@ -9,11 +9,15 @@ from starlite.routes.base import BaseRoute
 from starlite.signature import get_signature_model
 
 if TYPE_CHECKING:
-    from pydantic.typing import AnyCallable
-
     from starlite.handlers.websocket import WebsocketRouteHandler
     from starlite.kwargs import KwargsModel
-    from starlite.types import AsyncAnyCallable, Receive, Send, WebSocketScope
+    from starlite.types import (
+        AnyCallable,
+        AsyncAnyCallable,
+        Receive,
+        Send,
+        WebSocketScope,
+    )
 
 
 class WebSocketRoute(BaseRoute):
@@ -27,7 +31,7 @@ class WebSocketRoute(BaseRoute):
         *,
         path: str,
         route_handler: "WebsocketRouteHandler",
-    ):
+    ) -> None:
         """This class handles a single Websocket Route.
 
         Args:
@@ -42,7 +46,7 @@ class WebSocketRoute(BaseRoute):
             handler_names=[get_name(cast("AnyCallable", route_handler.fn))],
         )
 
-    async def handle(self, scope: "WebSocketScope", receive: "Receive", send: "Send") -> None:
+    async def handle(self, scope: "WebSocketScope", receive: "Receive", send: "Send") -> None:  # type: ignore[override]
         """ASGI app that creates a WebSocket from the passed in args, and then
         awaits the handler function.
 
