@@ -1,7 +1,7 @@
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Union, cast
 from urllib.parse import urlencode
 
-from orjson import dumps
+from orjson import dumps, loads
 from pydantic import BaseModel
 from starlette.testclient import TestClient as StarletteTestClient
 
@@ -9,6 +9,7 @@ from starlite.app import DEFAULT_CACHE_CONFIG, Starlite
 from starlite.connection import Request
 from starlite.enums import HttpMethod, ParamType, RequestEncodingType, ScopeType
 from starlite.exceptions import MissingDependencyException
+from starlite.utils import default_serializer
 
 if TYPE_CHECKING:
     from typing_extensions import Literal
@@ -44,7 +45,12 @@ if TYPE_CHECKING:
     )
 
 try:
-    from requests.models import RequestEncodingMixin
+    from httpx._content import (
+        encode_json,
+        encode_multipart_data,
+        encode_urlencoded_data,
+    )
+    from httpx._types import FileTypes  # noqa: TC002
 except ImportError as e:
     raise MissingDependencyException(
         "To use starlite.testing, install starlite with 'testing' extra, e.g. `pip install starlite[testing]`"
@@ -54,24 +60,9 @@ __all__ = [
     "TestClient",
     "create_test_client",
     "RequestFactory",
-    "create_test_request",
 ]
 
 
-class RequestEncoder(RequestEncodingMixin):
-    def multipart_encode(self, data: Dict[str, Any]) -> Tuple[bytes, str]:
-        class ForceMultipartDict(dict):
-            # code borrowed from here:
-            # https://github.com/encode/starlette/blob/d222b87cb4601ecda5d642ab504a14974d364db4/tests/test_formparsers.py#L14
-            def __bool__(self) -> bool:
-                return True
-
-        return self._encode_files(ForceMultipartDict(), data)  # type: ignore
-
-    def url_encode(self, data: Dict[str, Any]) -> bytes:
-        return self._encode_params(data).encode("utf-8")  # type: ignore
-
-
 class TestClient(StarletteTestClient):
     app: Starlite  # type: ignore[assignment]
     """
@@ -108,22 +99,17 @@ class TestClient(StarletteTestClient):
             backend_options=backend_options,
         )
 
-    def __enter__(self, *args: Any, **kwargs: Dict[str, Any]) -> "TestClient":
+    def __enter__(self) -> "TestClient":
         """Starlette's `TestClient.__enter__()` return value is strongly typed
         to return their own `TestClient`, i.e., not-generic to support
         subclassing.
 
-        We override here to provide a nicer typing experience for our users.
-
-        Args:
-            *args : Any
-            **kwargs : Any
-                `*args, **kwargs` passed straight through to `Starlette.testing.TestClient.__enter__()`
+        We override here to provide a nicer typing experience for our user
 
         Returns:
             TestClient
         """
-        return super().__enter__(*args, **kwargs)  # type:ignore[return-value]
+        return super().__enter__()  # pyright: ignore
 
 
 def create_test_client(
@@ -353,6 +339,7 @@ class RequestFactory:
         session: Optional[Dict[str, Any]] = None,
         user: Any = None,
         auth: Any = None,
+        query_params: Optional[Dict[str, Union[str, List[str]]]] = None,
     ) -> Dict[str, Any]:
         """Create the scope for the [Request][starlite.connection.Request].
 
@@ -365,6 +352,8 @@ class RequestFactory:
         Returns:
             A dictionary that can be passed as a scope to the [Request][starlite.connection.Request] c'tor.
         """
+        if session is None:
+            session = {}
 
         return dict(
             type=ScopeType.HTTP,
@@ -378,6 +367,9 @@ class RequestFactory:
             session=session,
             user=user,
             auth=auth,
+            query_string=urlencode(query_params, doseq=True).encode() if query_params else b"",
+            path_params=[],
+            client=(self.server, self.port),
         )
 
     @classmethod
@@ -435,6 +427,8 @@ class RequestFactory:
         auth: Any = None,
         request_media_type: RequestEncodingType = RequestEncodingType.JSON,
         data: Optional[Union[Dict[str, Any], "BaseModel"]] = None,
+        files: Optional[Union[Dict[str, FileTypes], List[Tuple[str, FileTypes]]]] = None,
+        query_params: Optional[Dict[str, Union[str, List[str]]]] = None,
     ) -> Request[Any, Any]:
         """Create a [Request][starlite.connection.Request] instance that has
         body (data)
@@ -451,27 +445,31 @@ class RequestFactory:
             request_media_type: The 'Content-Type' header of the request.
             data: A value for the request's body. Can be either a pydantic model instance
                 or a string keyed dictionary.
+            query_params: A dictionary of values from which the request's query will be generated.
+
         Returns:
             A [Request][starlite.connection.Request] instance
         """
 
-        scope = self._create_scope(path, http_method, session, user, auth)
+        scope = self._create_scope(
+            path=path, http_method=http_method, session=session, user=user, auth=auth, query_params=query_params
+        )
 
         headers = headers or {}
         if data:
             if isinstance(data, BaseModel):
                 data = data.dict()
             if request_media_type == RequestEncodingType.JSON:
-                body = dumps(data)
-                headers["Content-Type"] = str(RequestEncodingType.JSON.value)
+                encoding_headers, stream = encode_json(data)
             elif request_media_type == RequestEncodingType.MULTI_PART:
-                body, content_type = RequestEncoder().multipart_encode(data)
-                headers["Content-Type"] = content_type
+                encoding_headers, stream = encode_multipart_data(data, files=files or [])
             else:
-                body = RequestEncoder().url_encode(data)
-                headers["Content-Type"] = str(RequestEncodingType.URL_ENCODED.value)
+                encoding_headers, stream = encode_urlencoded_data(loads(dumps(data, default=default_serializer)))
+            headers.update(encoding_headers)
+            body = b""
+            for chunk in stream:
+                body += chunk
             scope["_body"] = body
-
         self._create_cookie_header(headers, cookies)
         scope["headers"] = self._build_headers(headers)
         return Request(scope=scope)  # type: ignore[arg-type]
@@ -497,14 +495,14 @@ class RequestFactory:
             user: A value for `request.scope["user"]`.
             auth: A value for `request.scope["auth"]`.
             query_params: A dictionary of values from which the request's query will be generated.
+
         Returns:
             A [Request][starlite.connection.Request] instance
         """
 
-        scope = self._create_scope(path, HttpMethod.GET, session, user, auth)
-
-        if query_params:
-            scope["query_string"] = urlencode(query_params, doseq=True).encode()
+        scope = self._create_scope(
+            path=path, http_method=HttpMethod.GET, session=session, user=user, auth=auth, query_params=query_params
+        )
 
         scope["headers"] = self._build_headers(headers, cookies)
         return Request(scope=scope)  # type: ignore[arg-type]
@@ -519,6 +517,7 @@ class RequestFactory:
         auth: Any = None,
         request_media_type: RequestEncodingType = RequestEncodingType.JSON,
         data: Optional[Union[Dict[str, Any], "BaseModel"]] = None,
+        query_params: Optional[Dict[str, Union[str, List[str]]]] = None,
     ) -> Request[Any, Any]:
         """Create a POST [Request][starlite.connection.Request] instance.
 
@@ -533,20 +532,23 @@ class RequestFactory:
             request_media_type: The 'Content-Type' header of the request.
             data: A value for the request's body. Can be either a pydantic model instance
                 or a string keyed dictionary.
+            query_params: A dictionary of values from which the request's query will be generated.
+
         Returns:
             A [Request][starlite.connection.Request] instance
         """
 
         return self._create_request_with_data(
-            HttpMethod.POST,
-            path,
-            headers,
-            cookies,
-            session,
-            user,
-            auth,
-            request_media_type,
-            data,
+            auth=auth,
+            cookies=cookies,
+            data=data,
+            headers=headers,
+            http_method=HttpMethod.POST,
+            path=path,
+            query_params=query_params,
+            request_media_type=request_media_type,
+            session=session,
+            user=user,
         )
 
     def put(
@@ -559,6 +561,7 @@ class RequestFactory:
         auth: Any = None,
         request_media_type: RequestEncodingType = RequestEncodingType.JSON,
         data: Optional[Union[Dict[str, Any], "BaseModel"]] = None,
+        query_params: Optional[Dict[str, Union[str, List[str]]]] = None,
     ) -> Request[Any, Any]:
         """Create a PUT [Request][starlite.connection.Request] instance.
 
@@ -573,20 +576,23 @@ class RequestFactory:
             request_media_type: The 'Content-Type' header of the request.
             data: A value for the request's body. Can be either a pydantic model instance
                 or a string keyed dictionary.
+            query_params: A dictionary of values from which the request's query will be generated.
+
         Returns:
             A [Request][starlite.connection.Request] instance
         """
 
         return self._create_request_with_data(
-            HttpMethod.PUT,
-            path,
-            headers,
-            cookies,
-            session,
-            user,
-            auth,
-            request_media_type,
-            data,
+            auth=auth,
+            cookies=cookies,
+            data=data,
+            headers=headers,
+            http_method=HttpMethod.PUT,
+            path=path,
+            query_params=query_params,
+            request_media_type=request_media_type,
+            session=session,
+            user=user,
         )
 
     def patch(
@@ -599,6 +605,7 @@ class RequestFactory:
         auth: Any = None,
         request_media_type: RequestEncodingType = RequestEncodingType.JSON,
         data: Optional[Union[Dict[str, Any], "BaseModel"]] = None,
+        query_params: Optional[Dict[str, Union[str, List[str]]]] = None,
     ) -> Request[Any, Any]:
         """Create a PATCH [Request][starlite.connection.Request] instance.
 
@@ -613,20 +620,23 @@ class RequestFactory:
             request_media_type: The 'Content-Type' header of the request.
             data: A value for the request's body. Can be either a pydantic model instance
                 or a string keyed dictionary.
+            query_params: A dictionary of values from which the request's query will be generated.
+
         Returns:
             A [Request][starlite.connection.Request] instance
         """
 
         return self._create_request_with_data(
-            HttpMethod.PATCH,
-            path,
-            headers,
-            cookies,
-            session,
-            user,
-            auth,
-            request_media_type,
-            data,
+            auth=auth,
+            cookies=cookies,
+            data=data,
+            headers=headers,
+            http_method=HttpMethod.PATCH,
+            path=path,
+            query_params=query_params,
+            request_media_type=request_media_type,
+            session=session,
+            user=user,
         )
 
     def delete(
@@ -637,6 +647,7 @@ class RequestFactory:
         session: Optional[Dict[str, Any]] = None,
         user: Any = None,
         auth: Any = None,
+        query_params: Optional[Dict[str, Union[str, List[str]]]] = None,
     ) -> Request[Any, Any]:
         """Create a POST [Request][starlite.connection.Request] instance.
 
@@ -648,108 +659,14 @@ class RequestFactory:
             session: A dictionary of session data.
             user: A value for `request.scope["user"]`.
             auth: A value for `request.scope["auth"]`.
+            query_params: A dictionary of values from which the request's query will be generated.
+
         Returns:
             A [Request][starlite.connection.Request] instance
         """
 
-        scope = self._create_scope(path, HttpMethod.DELETE, session, user, auth)
+        scope = self._create_scope(
+            path=path, http_method=HttpMethod.DELETE, session=session, user=user, auth=auth, query_params=query_params
+        )
         scope["headers"] = self._build_headers(headers, cookies)
         return Request(scope=scope)  # type: ignore[arg-type]
-
-
-def create_test_request(
-    app: Starlite = Starlite(route_handlers=[]),
-    auth: Any = None,
-    content: Optional[Union[Dict[str, Any], "BaseModel"]] = None,
-    cookie: Optional[Union[List["Cookie"], str]] = None,
-    headers: Optional[Dict[str, str]] = None,
-    http_method: HttpMethod = HttpMethod.GET,
-    path: str = "",
-    port: int = 3000,
-    query: Optional[Dict[str, Union[str, List[str]]]] = None,
-    request_media_type: RequestEncodingType = RequestEncodingType.JSON,
-    root_path: str = "/",
-    scheme: str = "http",
-    server: str = "test.org",
-    user: Any = None,
-) -> Request[Any, Any]:
-    """Create a [Request][starlite.connection.Request] instance using the
-    passed in parameters.
-
-    Args:
-        app: An instance of [Starlite][starlite.app.Starlite] to set as `request.scope["app"]`.
-        auth: A value for `request.scope["auth"]`
-        content: A value for the request's body. Can be either a pydantic model instance or a string keyed dictionary.
-        cookie: A string representing the cookie header or a list of "Cookie" instances. This value can include multiple
-            cookies.
-        headers: A string / string dictionary of headers.
-        http_method: The request's HTTP method.
-        path: The request's path.
-        port: The request's port.
-        query: A string keyed dictionary of values from which the request's query will be generated.
-        request_media_type: The 'Content-Type' header of the request.
-        root_path: Root path for the server.
-        scheme: Scheme for the server.
-        server: Domain for the server.
-        user: A value for `request.scope["user"]`
-    Returns:
-        A [Request][starlite.connection.Request] instance.
-    """
-
-    request_factory = RequestFactory(
-        app=app,
-        server=server,
-        port=port,
-        root_path=root_path,
-        scheme=scheme,
-    )
-
-    if http_method == HttpMethod.GET:
-        return request_factory.get(
-            path=path or "/",
-            headers=headers,
-            cookies=cookie,
-            user=user,
-            auth=auth,
-            query_params=query,
-        )
-    elif http_method == HttpMethod.POST:
-        return request_factory.post(
-            path=path or "/",
-            headers=headers,
-            cookies=cookie,
-            user=user,
-            auth=auth,
-            request_media_type=request_media_type,
-            data=content,
-        )
-    elif http_method == HttpMethod.PUT:
-        return request_factory.put(
-            path=path or "/",
-            headers=headers,
-            cookies=cookie,
-            user=user,
-            auth=auth,
-            request_media_type=request_media_type,
-            data=content,
-        )
-    elif http_method == HttpMethod.PATCH:
-        return request_factory.patch(
-            path=path or "/",
-            headers=headers,
-            cookies=cookie,
-            user=user,
-            auth=auth,
-            request_media_type=request_media_type,
-            data=content,
-        )
-    elif http_method == HttpMethod.DELETE:
-        return request_factory.delete(
-            path=path or "/",
-            headers=headers,
-            cookies=cookie,
-            user=user,
-            auth=auth,
-        )
-
-    raise ValueError(f"Cannot create request for HTTP method {http_method.value}")
